changeset 2338:36cc4399937f

* keyboard.c (Fsuspend_emacs): Change suspend-hooks back to suspend-hook and make it a normal hook.
author Jim Blandy <jimb@redhat.com>
date Wed, 24 Mar 1993 01:46:10 +0000
parents 2ee64176069c
children a302de11debf
files src/keyboard.c
diffstat 1 files changed, 4 insertions(+), 13 deletions(-) [+]
line wrap: on
line diff
--- a/src/keyboard.c	Tue Mar 23 18:27:03 1993 +0000
+++ b/src/keyboard.c	Wed Mar 24 01:46:10 1993 +0000
@@ -4151,17 +4151,9 @@
   if (!NILP (stuffstring))
     CHECK_STRING (stuffstring, 0);
 
-  /* Run the functions in suspend-hooks.  */
-  tem = Fsymbol_value (intern ("suspend-hooks"));
-  while (CONSP (tem))
-    {
-      Lisp_Object val;
-      GCPRO2 (stuffstring, tem);
-      val = call0 (Fcar (tem));
-      UNGCPRO;
-      tem = Fcdr (tem);
-      if (!EQ (val, Qnil)) return Qnil;
-    }
+  /* Run the functions in suspend-hook.  */
+  if (!NILP (Vrun_hooks))
+    call1 (Vrun_hooks, intern ("suspend-hook"));
 
   GCPRO1 (stuffstring);
   get_frame_size (&old_width, &old_height);
@@ -4180,8 +4172,7 @@
   if (width != old_width || height != old_height)
     change_frame_size (0, height, width, 0, 0);
 
-  /* Call value of suspend-resume-hook
-     if it is bound and value is non-nil.  */
+  /* Run suspend-resume-hook.  */
   if (!NILP (Vrun_hooks))
     call1 (Vrun_hooks, intern ("suspend-resume-hook"));